<?php

use Phinx\Migration\AbstractMigration;
use Phinx\Db\Adapter\MysqlAdapter;

class AddBoutique extends AbstractMigration
{
    public function change()
    {
        $this
            ->table("boutique", ['id' => false, 'primary_key' => ["boutique_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('boutique_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('boutique_nom', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'boutique_id'])
            ->addColumn('boutique_domaine', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'boutique_nom'])
            ->addColumn('boutique_dossier', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'boutique_domaine'])
            ->addColumn('boutique_admin_email', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'boutique_dossier'])
            ->addColumn('boutique_contact_email', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'boutique_admin_email'])
            ->addColumn('langue_id', 'integer', ['null' => false, 'default' => '1', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'boutique_contact_email', 'signed' => false])
            ->addColumn('devise_id', 'integer', ['null' => false, 'default' => '1', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'langue_id', 'signed' => false])
            ->addColumn('actif_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'devise_id', 'signed' => false])
            ->addColumn('boutique_tva', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'actif_id'])
            ->addColumn('boutique_footer_pdf', 'text', ['null' => false, 'limit' => 65535, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'boutique_tva'])
            ->addForeignKey('langue_id', 'langue', 'langue_id', array(
                'delete' => 'RESTRICT',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('devise_id', 'devise', 'devise_id', array(
                'delete' => 'RESTRICT',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('actif_id', 'actif', 'actif_id', array(
                'delete' => 'RESTRICT',
                'update' => 'CASCADE'
            ))
            ->addIndex(['langue_id'], ['name' => "langue_id", 'unique' => false])
            ->addIndex(['devise_id'], ['name' => "devise_id", 'unique' => false])
            ->addIndex(['actif_id'], ['name' => "actif_id", 'unique' => false])
            ->create();

        $this
            ->table("boutique_config", ['id' => false, 'primary_key' => ["boutique_config_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('boutique_config_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('boutique_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'boutique_config_id', 'signed' => false])
            ->addColumn('boutique_config_key', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'boutique_id'])
            ->addColumn('boutique_config_value', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'boutique_config_key'])
            ->addColumn('boutique_config_desc', 'text', ['null' => false, 'limit' => 65535, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'boutique_config_value'])
            ->addForeignKey('boutique_id', 'boutique', 'boutique_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['boutique_id'], ['name' => "boutique_id", 'unique' => false])
            ->create();

        $this
            ->table("boutique_statut", ['id' => false, 'primary_key' => ["boutique_statut_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('boutique_statut_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('boutique_statut_nom', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'boutique_statut_id'])
            ->addColumn('boutique_statut_image', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'boutique_statut_nom'])
            ->addColumn('boutique_statut_rang', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'boutique_statut_image'])
            ->create();

        $this
            ->table("boutique_tracking", ['id' => false, 'primary_key' => ["boutique_tracking_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('boutique_tracking_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('boutique_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'boutique_tracking_id', 'signed' => false])
            ->addColumn('boutique_tracking_identifiant', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'boutique_id'])
            ->addColumn('boutique_tracking_script', 'text', ['null' => false, 'limit' => 65535, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'boutique_tracking_identifiant'])
            ->addColumn('boutique_tracking_position', 'enum', ['null' => false, 'limit' => 10, 'values' => ['header', 'footer', 'body_begin', ''], 'after' => 'boutique_tracking_script'])
            ->addForeignKey('boutique_id', 'boutique', 'boutique_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['boutique_id'], ['name' => "boutique_id", 'unique' => false])
            ->create();
    }
}
